(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    153454,       3080]*)
(*NotebookOutlinePosition[    156039,       3148]*)
(*  CellTagsIndexPosition[    155731,       3137]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["matrixrepresentationvc", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["matrixrepresentationvc", "MR"],
  "[",
  StyleBox["op", "IT"],
  ", ",
  StyleBox["basis", "IT"],
  "] computes the matrix representation of the operator op in the basis of \
occupation number vectors basis.\n\[FilledSmallSquare] ",
  StyleBox["matrixrepresentationvcsparse", "MR"],
  "[",
  StyleBox["op", "IT"],
  ", ",
  StyleBox["basis", "IT"],
  "] computes the (sparse) matrix representation of the operator op in the \
basis of occupation number vectors basis.\n\[FilledSmallSquare] ",
  StyleBox["matrixrepresentationvcfast", "MR"],
  "[",
  StyleBox["op", "IT"],
  ", ",
  StyleBox["basis", "IT"],
  "] computes the matrix representation of the operator op in the basis of \
occupation number vectors basis using an improved approach.\n\
\[FilledSmallSquare] ",
  StyleBox["matrixrepresentationop", "MR"],
  "[",
  StyleBox["op", "IT"],
  ", ",
  StyleBox["basis", "IT"],
  "] computes the matrix representation of the operator op in the basis of \
creation operators basis.\n\[FilledSmallSquare] ",
  StyleBox["matrixrepresentationvc", "MR"],
  "[",
  StyleBox["op", "IT"],
  ", ",
  StyleBox["basisL", "IT"],
  ", ",
  StyleBox["basisR", "IT"],
  "] returns the matrix representation of the operator ",
  StyleBox["op", "IT"],
  " in the case of different basis sets of occupation number vectors for \
left-multiplication (bra) and right-multiplication (ket).\n\
\[FilledSmallSquare] ",
  StyleBox["matrixrepresentationop", "MR"],
  "[",
  StyleBox["op", "IT"],
  ", ",
  StyleBox["basisL", "IT"],
  ", ",
  StyleBox["basisR", "IT"],
  "] returns the matrix representation of the operator op in the case of \
different basis sets of creation operators for left-multiplication (bra) and \
right-multiplication (ket).\n\[FilledSmallSquare] ",
  StyleBox["makematricesbzvc[", "MR"],
  StyleBox["op", "IT"],
  StyleBox[", ", "MR"],
  StyleBox["bzvc", "IT"],
  StyleBox["] ", "MR"],
  "and ",
  StyleBox["makematricesbzop[", "MR"],
  StyleBox["op", "IT"],
  StyleBox[", ", "MR"],
  StyleBox["bzop", "IT"],
  StyleBox["] ", "MR"],
  "produce a table of operator matrices for all invariant subspaces in basis \
",
  StyleBox["bzvc", "IT"],
  " or ",
  StyleBox["bzop", "IT"],
  "."
}], "Usage",
  CellTags->{
  "matrixrepresentationvc", "matrixrepresentationvcsparse", 
    "matrixrepresentationvcfast", "matrixrepresentationop", 
    "makematricesbzvc", "makematricesbzop"}],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["braket",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ap",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["vc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["vacuum",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["makebasis",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " to be a fermionic operator"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\), "\[IndentingNewLine]", 
    \(\(snegrealconstants[U, t, \[Epsilon]];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Two-site Hubbard Hamiltonian", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 2;\)\), "\[IndentingNewLine]", 
    \(H = hamiltonian[Hubbard, c[], n, U, t, \[Epsilon]]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Epsilon]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{"t", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{"\[Epsilon]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "Construct a basis with well defined ",
  Cell[BoxData[
      \(TraditionalForm\`\((Q, S\_z)\)\)]],
  " quantum numbers"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ops = Table[c[i], {i, n}];\)\), "\[IndentingNewLine]", 
    \(\(makebasis[ops];\)\), "\[IndentingNewLine]", 
    \(\(bz = qszbasisvc[ops];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[bz]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[EmptyRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm], ",", 
                  TagBox[
                    RowBox[{
                      TagBox[
                        StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[FilledRectangle]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                      TagBox[
                        StyleBox["\<\"\[EmptyRectangle]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                      TagBox[
                        StyleBox["\<\"\[RightAngleBracket]\"\>",
                          FontColor->RGBColor[0, 0.392187, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0.0, 0.39219300000000001, 0.0]]&)]}],
                    DisplayForm]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                TagBox[
                  RowBox[{
                    TagBox[
                      StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                    TagBox[
                      StyleBox["\<\"\[FilledRectangle]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                    TagBox[
                      StyleBox["\<\"\[RightAngleBracket]\"\>",
                        FontColor->RGBColor[0, 0.392187, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0.0, 0.39219300000000001, 0.0]]&)]}],
                  DisplayForm], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[9]//MatrixForm="]
}, Open  ]],

Cell["Construct the Hamiltonian matrices in all subspaces.", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(matvc = 
        Map[{First[#], 
              matrixrepresentationvc[
                H, #\[LeftDoubleBracket]2\[RightDoubleBracket]\ ]} &, 
          bz];\)\), "\[IndentingNewLine]", 
    \(MatrixForm@
      Map[{First[#], 
            MatrixForm[#\[LeftDoubleBracket]2\[RightDoubleBracket]]} &, 
        matvc]\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\[Epsilon]", "t"},
                      {"t", "\[Epsilon]"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({\(-1\), 1\/2}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\[Epsilon]", "t"},
                      {"t", "\[Epsilon]"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, \(-1\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U + 2\ \[Epsilon]\), \(-t\), "t", "0"},
                      {\(-t\), \(2\ \[Epsilon]\), "0", \(-t\)},
                      {"t", "0", \(2\ \[Epsilon]\), "t"},
                      {"0", \(-t\), "t", \(U + 2\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, 1}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({1, \(-\(1\/2\)\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U + 3\ \[Epsilon]\), \(-t\)},
                      {\(-t\), \(U + 3\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({1, 1\/2}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U + 3\ \[Epsilon]\), \(-t\)},
                      {\(-t\), \(U + 3\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({2, 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ U + 4\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[11]//MatrixForm="]
}, Open  ]],

Cell["Switch to creation number representation of the basis states", \
"ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bzop = bzvc2bzop[bz];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[bzop]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), \({1}\)},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({0, \(-1\)}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({1, \(-\(1\/2\)\)}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[13]//MatrixForm="]
}, Open  ]],

Cell["\<\
Check that the same Hamiltonian matrices are also obtained  in the \
creation operator representation\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(matop = 
        Map[{First[#], 
              matrixrepresentationop[
                H, #\[LeftDoubleBracket]2\[RightDoubleBracket]\ ]} &, 
          bzop];\)\), "\[IndentingNewLine]", 
    \(MatrixForm@
      Map[{First[#], 
            MatrixForm[#\[LeftDoubleBracket]2\[RightDoubleBracket]]} &, 
        matop]\), "\[IndentingNewLine]", 
    \(matop \[Equal] matvc\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({\(-1\), \(-\(1\/2\)\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\[Epsilon]", "t"},
                      {"t", "\[Epsilon]"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({\(-1\), 1\/2}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"\[Epsilon]", "t"},
                      {"t", "\[Epsilon]"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, \(-1\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U + 2\ \[Epsilon]\), \(-t\), "t", "0"},
                      {\(-t\), \(2\ \[Epsilon]\), "0", \(-t\)},
                      {"t", "0", \(2\ \[Epsilon]\), "t"},
                      {"0", \(-t\), "t", \(U + 2\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({0, 1}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({1, \(-\(1\/2\)\)}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U + 3\ \[Epsilon]\), \(-t\)},
                      {\(-t\), \(U + 3\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({1, 1\/2}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(U + 3\ \[Epsilon]\), \(-t\)},
                      {\(-t\), \(U + 3\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({2, 0}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ U + 4\ \[Epsilon]\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[15]//MatrixForm="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["More complex example: five site Hubbard model", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 5;\)\), "\[IndentingNewLine]", 
    \(\(H = 
        hamiltonian[Hubbard, c[], n, U, 
          t, \[Epsilon]];\)\), "\[IndentingNewLine]", 
    \(\(H = 
        H /. {\[Epsilon] \[Rule] 0, U \[Rule] 1, 
            t \[Rule] \(-0.2\)};\)\), "\[IndentingNewLine]", 
    \(\(ops = Table[c[i], {i, n}];\)\), "\n", 
    \(\(makebasis[ops];\)\), "\n", 
    \(\(bz = qszbasisvc[ops];\)\), "\[IndentingNewLine]", 
    \(\(bz1 = \(Select[bz, #[\([1]\)] == {0, 1/2} &]\)[\([1, 
            2]\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Matrix dimension: \>", 
        Length[bz1]];\)\), "\[IndentingNewLine]", 
    \(Timing[\(mat = 
          matrixrepresentationvc[H, bz1];\)]\), "\[IndentingNewLine]", 
    \(Timing[\(matfast = 
          matrixrepresentationvcfast[H, bz1];\)]\), "\[IndentingNewLine]", 
    \(Timing[\(matsparse = 
          matrixrepresentationvcsparse[H, bz1];\)]\), "\[IndentingNewLine]", 
    \(mat \[Equal] matfast\), "\[IndentingNewLine]", 
    \(mat \[Equal] matsparse\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    InterpretationBox[\("Matrix dimension: "\[InvisibleSpace]100\),
      SequenceForm[ "Matrix dimension: ", 100],
      Editable->False]], "Print",
  CellLabel->"From In[17]:="],

Cell[BoxData[
    \({4.888257`\ Second, Null}\)], "Output",
  CellLabel->"Out[25]="],

Cell[BoxData[
    \({1.5667619999999998`\ Second, Null}\)], "Output",
  CellLabel->"Out[26]="],

Cell[BoxData[
    \({1.5737610000000004`\ Second, Null}\)], "Output",
  CellLabel->"Out[27]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[28]="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
Plot the structure of the Hamiltonian matrix and compute the lowest \
five eigenvalues using the Arnoldi (Lanczos) method\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ArrayPlot[mat];\)\), "\[IndentingNewLine]", 
    \(Timing[
      Eigenvalues[mat, 5, 
        Method \[Rule] {"\<Arnoldi\>", Shift \[Rule] \(-0.5\)}]]\)}], "Input",\

  CellLabel->"In[30]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0238095 0.00952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.02381 .02381 translate
.95238 .95238 scale
100 string
100 100 8 [100 0 0 100 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE600E6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE680E6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFFF80E6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600FFFFE6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6E680E6FFE6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6FF80E6FFE6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680E6E6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFF
FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600FFFFFFFFFFFFFFFFFFE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFF
FFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFF
FFFFFFFFFFE6FFFFFFFFFFFFE6FFE600E6FFFFFFFFFFFFFFFFE6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFF
FFFFFFFFE6FFFFFFFFFFFFE6FFFF80E6FFFFFFFFFFFFFFFFE6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFFFE6FFFFFFFFFFFFFFFFE680FFFFE6FFFFFFFFFFFFE6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFF
FFFFE6FFFFFFFFFFFFFFE6E600E6FFE6FFFFFFFFFFFFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFE6FFFFFFFFFFFFFFE6FF80E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF
E6FFFFFFFFFFFFFFFFE680FFE6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFE6
FFFFFFFFFFFFFFFFE6FFE6E6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFE6FF
FFFFFFFFFFFFFFFF80E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE600FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE6FFFF00E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE680FFFFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E6E680E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6
FF00E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6
FFFFE6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE680
E6E6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80E6
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE600E6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE600E6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFFF80E6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFFE6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6E680E6FFE6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6FFFFE6FFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600FFE6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680E6E6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF80E6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFFFFFFFFFFFFFFFFE6FFFF
FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE600E6FFFFFFFFFFFFFFFFE6FFFFFF
FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFF
FFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFFF00E6FFFFFFFFFFFFFFFFE6FFFFFFFFFF
FFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFFE6FFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6E6FFE6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFF
FFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6FF80E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFE6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF
E6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE6FFFFFFFFFFFFFFFFE600E6E6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE6FFFFFFFFFFFFFFFFFF80E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFE6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE680FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFE600E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE6FFFF00E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE6E680E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE6FF80E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE680FFE6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE680E6E6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFE680FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6
FFE680E6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FF
E680E6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFFF
FFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600
FFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6E600E6
FFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6FF80E6FF
E6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600FFE6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680E6E6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF80E6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFFFFFFFFFF
FFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE680E6FFFFFFFFFFFF
FFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE6FFE6FFFFFFFFFFFFFF
FFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFFF80E6FFFFFFFFFFFFFFFF
E6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600FFFFE6FFFFFFFFFFFFE6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6E680E6FFE6FFFFFFFFFFFFE6FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFE6FF00E6FFE6FFFFFFFFFFFFE6FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFE6FFFFFFFFFFFFFFE6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE600E6E6FFFFFFFFFFFFFFE6FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF80E6FFFFFFFFFFFFFFFFE6FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE6FFE6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE6FFFFFFFFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE6FFFFFFFFFFFFE6FFFF80E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE6FFFFFFFFFFFFFFFFE680FFFFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE6FFFFFFFFFFFFFFE6E600E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE6FFFFFFFFFFFFFFE6FF00E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE6FFFFFFFFFFFFFFFFE680FFE6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE6FFFFFFFFFFFFFFFFE680E6E6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E6FFFFFFFFFFFFFFFFFF00E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE6FFE680E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE6FFFF80E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE680FFFFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE6E680E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE6FF80E6FFE6FFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE600FFE6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E600E6E6FFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00E6FFFFFFFFFFFFFFFFE6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[30]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`00000P00000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`00
00<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703o
ool100000040oooo00000`000000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?oo
o`3oool0o`3ooolL0?ooo`4000000@3oool000030000003oool0oooo0?l0oooo703oool100000040
oooo00000`000000oooo0?ooo`3g0?ooo`<0i^KV5P3oool30>KViP8000001P3oool100000040oooo
00000`000000oooo0?ooo`3g0?ooo`<0i^KV5P3oool30>KViP8000001P3oool100000040oooo0000
0`000000oooo0?ooo`3g0?ooo`<0i^KV5P3oool30>KViP8000001P3oool100000040oooo00000`00
0000oooo0?ooo`3e0?ooo`80i^KV4@3oool30>KViP80oooo0`3Vi^H300000080i^KV1P3oool10000
0040oooo00000`000000oooo0?ooo`3e0?ooo`80i^KV4@3oool30>KViP80oooo0`3Vi^H300000080
i^KV1P3oool100000040oooo00000`000000oooo0?ooo`3e0?ooo`80i^KV4@3oool30>KViP80oooo
0`3Vi^H300000080i^KV1P3oool100000040oooo00000`000000oooo0?ooo`3b0?ooo`<0i^KV403o
ool30>KViP<0oooo0P3Vi^H30820P0<0i^KV203oool100000040oooo00000`000000oooo0?ooo`3b
0?ooo`<0i^KV403oool30>KViP<0oooo0P3Vi^H30820P0<0i^KV203oool100000040oooo00000`00
0000oooo0?ooo`3b0?ooo`<0i^KV403oool30>KViP<0oooo0P3Vi^H30820P0<0i^KV203oool10000
0040oooo00000`000000oooo0?ooo`3_0?ooo`<0i^KV403oool30>KViPH0oooo0P20P8030>KViP/0
oooo0@0000010?ooo`0000<000000?ooo`3oool0k`3oool30>KViQ00oooo0`3Vi^H60?ooo`80P820
0`3Vi^H;0?ooo`4000000@3oool000030000003oool0oooo0>`0oooo0`3Vi^HF0?ooo`<0i^KV0`00
00050?ooo`<0i^KV203oool100000040oooo00000`000000oooo0?ooo`3/0?ooo`<0i^KV5P3oool3
0>KViP<000001@3oool30>KViPP0oooo0@0000010?ooo`0000<000000?ooo`3oool0k03oool30>KV
iQH0oooo0`3Vi^H3000000D0oooo0`3Vi^H80?ooo`4000000@3oool000030000003oool0oooo0>X0
oooo0P3Vi^HD0?ooo`D0i^KV0`20P8030>KViP80oooo0`3Vi^H;0?ooo`4000000@3oool000030000
003oool0oooo0>X0oooo0P3Vi^HD0?ooo`D0i^KV0`20P8030>KViP80oooo0`3Vi^H;0?ooo`400000
0@3oool000030000003oool0oooo0>X0oooo0P3Vi^HD0?ooo`D0i^KV0`20P8030>KViP80oooo0`3V
i^H;0?ooo`4000000@3oool000030000003oool0oooo0>L0oooo0`3Vi^HC0?ooo`<0i^KV0P3oool3
0820P0<0i^KV0`3oool20>KViPh0oooo0@0000010?ooo`0000<000000?ooo`3oool0i`3oool30>KV
iQ<0oooo0`3Vi^H20?ooo`<0P8200`3Vi^H30?ooo`80i^KV3P3oool100000040oooo00000`000000
oooo0?ooo`3W0?ooo`<0i^KV4`3oool30>KViP80oooo0`20P8030>KViP<0oooo0P3Vi^H>0?ooo`40
00000@3oool000030000003oool0oooo0>@0oooo0`3Vi^HF0?ooo`<0i^KV0P20P8030?ooo`<0i^KV
4`3oool100000040oooo00000`000000oooo0?ooo`3T0?ooo`<0i^KV5P3oool30>KViP80P8200`3o
ool30>KViQ<0oooo0@0000010?ooo`0000<000000?ooo`3oool0h@3oool30>KViQH0oooo0`3Vi^H3
0820P0D0i^KV5P3oool100000040oooo00000`000000oooo0?ooo`3Q0?ooo`<0i^KV5P3oool30>KV
iP<0P8201@3Vi^HF0?ooo`4000000@3oool000030000003oool0oooo0>40oooo0`3Vi^HF0?ooo`<0
i^KV0`20P8050>KViQH0oooo0@0000010?ooo`0000<000000?ooo`3oool0g`3oool20>KViQ`0oooo
0`3Vi^HK0?ooo`4000000@3oool000030000003oool0oooo0=l0oooo0P3Vi^HL0?ooo`<0i^KV6`3o
ool100000040oooo00000`000000oooo0?ooo`3O0?ooo`80i^KV703oool30>KViQ/0oooo0@000001
0?ooo`0000<000000?ooo`3oool0`@3oool20>KViQT0oooo0`3Vi^HF0?ooo`80i^KV0`00000I0?oo
o`80i^KV1P3oool100000040oooo00000`000000oooo0?ooo`310?ooo`80i^KV6@3oool30>KViQH0
oooo0P3Vi^H3000001T0oooo0P3Vi^H60?ooo`4000000@3oool000030000003oool0oooo0;h0oooo
0`3Vi^HH0?ooo`<0i^KV403oool30>KViP<0oooo0`3Vi^H20820P0<0i^KV5P3oool30>KViPP0oooo
0@0000010?ooo`0000<000000?ooo`3oool0_P3oool30>KViQP0oooo0`3Vi^H@0?ooo`<0i^KV0`3o
ool30>KViP80P8200`3Vi^HF0?ooo`<0i^KV203oool100000040oooo00000`000000oooo0?ooo`2n
0?ooo`<0i^KV603oool30>KViQ00oooo0`3Vi^H30?ooo`<0i^KV0P20P8030>KViQH0oooo0`3Vi^H8
0?ooo`4000000@3oool000030000003oool0oooo0;/0oooo0`3Vi^HH0?ooo`<0i^KV4@3oool20>KV
iP<0oooo0`3Vi^H300000080i^KV5P3oool30>KViP/0oooo0@0000010?ooo`0000<000000?ooo`3o
ool0^`3oool30>KViQP0oooo0`3Vi^HA0?ooo`80i^KV0`3oool30>KViP<000000P3Vi^HF0?ooo`<0
i^KV2`3oool100000040oooo00000`000000oooo0?ooo`2k0?ooo`<0i^KV603oool30>KViQ40oooo
0P3Vi^H30?ooo`<0i^KV0`0000020>KViQH0oooo0`3Vi^H;0?ooo`4000000@3oool000030000003o
ool0oooo0;P0oooo0`3Vi^HI0?ooo`80i^KV4@3oool30>KViPD0oooo0`20P8030>KViQH0oooo0P3V
i^H>0?ooo`4000000@3oool000030000003oool0oooo0;P0oooo0`3Vi^HI0?ooo`80i^KV4@3oool3
0>KViPD0oooo0`20P8030>KViQH0oooo0P3Vi^H>0?ooo`4000000@3oool000030000003oool0oooo
0;P0oooo0`3Vi^HI0?ooo`80i^KV4@3oool30>KViPD0oooo0`20P8030>KViQH0oooo0P3Vi^H>0?oo
o`4000000@3oool000030000003oool0oooo0;H0oooo0P3Vi^HI0?ooo`<0i^KV5P3oool20>KViP<0
P8201P3oool20>KViQ40oooo0`3Vi^H@0?ooo`4000000@3oool000030000003oool0oooo0;H0oooo
0P3Vi^HI0?ooo`<0i^KV5P3oool20>KViP<0P8201P3oool20>KViQ40oooo0`3Vi^H@0?ooo`400000
0@3oool000030000003oool0oooo0;<0oooo0`3Vi^HH0?ooo`<0i^KV4`3oool60>KViP8000000`3V
i^H30?ooo`<0i^KV403oool30>KViQ<0oooo0@0000010?ooo`0000<000000?ooo`3oool0/`3oool3
0>KViQP0oooo0`3Vi^HC0?ooo`H0i^KV0P0000030>KViP<0oooo0`3Vi^H@0?ooo`<0i^KV4`3oool1
00000040oooo00000`000000oooo0?ooo`2c0?ooo`<0i^KV603oool30>KViQ<0oooo1P3Vi^H20000
00<0i^KV0`3oool30>KViQ00oooo0`3Vi^HC0?ooo`4000000@3oool000030000003oool0oooo0;00
oooo0`3Vi^HI0?ooo`80i^KV4`3oool30>KViP<0oooo0`20P8020>KViP<0oooo0`3Vi^H@0?ooo`<0
i^KV5P3oool100000040oooo00000`000000oooo0?ooo`2`0?ooo`<0i^KV6@3oool20>KViQ<0oooo
0`3Vi^H30?ooo`<0P8200P3Vi^H30?ooo`<0i^KV403oool30>KViQH0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0/03oool30>KViQT0oooo0P3Vi^HC0?ooo`<0i^KV0`3oool30820P080i^KV0`3o
ool30>KViQ00oooo0`3Vi^HF0?ooo`4000000@3oool000030000003oool0oooo0:d0oooo0`3Vi^HI
0?ooo`<0i^KV5@3oool30>KViP<0P8200`3oool20>KViQ@0oooo0P3Vi^HI0?ooo`4000000@3oool0
00030000003oool0oooo0:d0oooo0`3Vi^HI0?ooo`<0i^KV5@3oool30>KViP<0P8200`3oool20>KV
iQ@0oooo0P3Vi^HI0?ooo`4000000@3oool000030000003oool0oooo0:/0oooo0P3Vi^HI0?ooo`<0
i^KV5P3oool20>KViP<0oooo1P3Vi^HC0?ooo`<0i^KV6`3oool100000040oooo00000`000000oooo
0?ooo`2[0?ooo`80i^KV6@3oool30>KViQH0oooo0P3Vi^H30?ooo`H0i^KV4`3oool30>KViQ/0oooo
0@0000010?ooo`0000<000000?ooo`3oool0Z`3oool20>KViQT0oooo0`3Vi^HF0?ooo`80i^KV0`3o
ool60>KViQ<0oooo0`3Vi^HK0?ooo`4000000@3oool000030000003oool0oooo0:P0oooo0`3Vi^HH
0?ooo`<0i^KV6@3oool20820P0<0i^KV5P3oool30>KViQh0oooo0@0000010?ooo`0000<000000?oo
o`3oool0Z03oool30>KViQP0oooo0`3Vi^HI0?ooo`80P8200`3Vi^HF0?ooo`<0i^KV7P3oool10000
0040oooo00000`000000oooo0?ooo`2X0?ooo`<0i^KV603oool30>KViQT0oooo0P20P8030>KViQH0
oooo0`3Vi^HN0?ooo`4000000@3oool000030000003oool0oooo0:D0oooo0`3Vi^Ha0?ooo`<0i^KV
0`00000H0?ooo`<0i^KV8@3oool100000040oooo00000`000000oooo0?ooo`2U0?ooo`<0i^KV<@3o
ool30>KViP<00000603oool30>KViR40oooo0@0000010?ooo`0000<000000?ooo`3oool0Y@3oool3
0>KViS40oooo0`3Vi^H3000001P0oooo0`3Vi^HQ0?ooo`4000000@3oool000030000003oool0oooo
0:80oooo0`3Vi^H/0?ooo`<0i^KV0P3oool30>KViP<0P8200`3Vi^HF0?ooo`80i^KV903oool10000
0040oooo00000`000000oooo0?ooo`2R0?ooo`<0i^KV;03oool30>KViP80oooo0`3Vi^H30820P0<0
i^KV5P3oool20>KViR@0oooo0@0000010?ooo`0000<000000?ooo`3oool0X03oool20>KViR`0oooo
0`3Vi^H30?ooo`80i^KV0`20P8030>KViQH0oooo0`3Vi^HV0?ooo`4000000@3oool000030000003o
ool0oooo0:00oooo0P3Vi^H/0?ooo`<0i^KV0`3oool20>KViP<0P8200`3Vi^HF0?ooo`<0i^KV9P3o
ool100000040oooo00000`000000oooo0?ooo`2P0?ooo`80i^KV;03oool30>KViP<0oooo0P3Vi^H3
0820P0<0i^KV5P3oool30>KViRH0oooo0@0000010?ooo`0000<000000?ooo`3oool0W@3oool30>KV
iR`0oooo0P3Vi^H60?ooo`8000000`3Vi^HF0?ooo`<0i^KV:@3oool100000040oooo00000`000000
oooo0?ooo`2M0?ooo`<0i^KV;03oool20>KViPH0oooo0P0000030>KViQH0oooo0`3Vi^HY0?ooo`40
00000@3oool000030000003oool0oooo09d0oooo0`3Vi^H/0?ooo`80i^KV1P3oool2000000<0i^KV
5P3oool30>KViRT0oooo0@0000010?ooo`0000<000000?ooo`3oool0VP3oool30>KViS40oooo0`3V
i^H30820P0D0oooo0`3Vi^H@0?ooo`<0i^KV;03oool100000040oooo00000`000000oooo0?ooo`2J
0?ooo`<0i^KV<@3oool30>KViP<0P8201@3oool30>KViQ00oooo0`3Vi^H/0?ooo`4000000@3oool0
00030000003oool0oooo09X0oooo0`3Vi^Ha0?ooo`<0i^KV0`20P8050?ooo`<0i^KV403oool30>KV
iR`0oooo0@0000010?ooo`0000<000000?ooo`3oool0U`3oool30>KViRl0oooo1@3Vi^H30820P0<0
i^KV0P3oool30>KViQ40oooo0P3Vi^H_0?ooo`4000000@3oool000030000003oool0oooo09L0oooo
0`3Vi^H_0?ooo`D0i^KV0`20P8030>KViP80oooo0`3Vi^HA0?ooo`80i^KV;`3oool100000040oooo
00000`000000oooo0?ooo`2E0?ooo`80i^KV;`3oool30>KViP<0oooo0P0000030>KViP<0oooo0P3V
i^HA0?ooo`<0i^KV<@3oool100000040oooo00000`000000oooo0?ooo`2E0?ooo`80i^KV;`3oool3
0>KViP<0oooo0P0000030>KViP<0oooo0P3Vi^HA0?ooo`<0i^KV<@3oool100000040oooo00000`00
0000oooo0?ooo`2E0?ooo`80i^KV;`3oool30>KViP<0oooo0P0000030>KViP<0oooo0P3Vi^HA0?oo
o`<0i^KV<@3oool100000040oooo00000`000000oooo0?ooo`2B0?ooo`<0i^KV<@3oool30>KViPD0
oooo0`3Vi^HC0?ooo`<0i^KV=03oool100000040oooo00000`000000oooo0?ooo`2B0?ooo`<0i^KV
<@3oool30>KViPD0oooo0`3Vi^HC0?ooo`<0i^KV=03oool100000040oooo00000`000000oooo0?oo
o`2B0?ooo`<0i^KV<@3oool30>KViPD0oooo0`3Vi^HC0?ooo`<0i^KV=03oool100000040oooo0000
0`000000oooo0?ooo`2?0?ooo`<0i^KV<@3oool30>KViP<0P8201@3Vi^HC0?ooo`<0i^KV=`3oool1
00000040oooo00000`000000oooo0?ooo`2?0?ooo`<0i^KV<@3oool30>KViP<0P8201@3Vi^HC0?oo
o`<0i^KV=`3oool100000040oooo00000`000000oooo0?ooo`2<0?ooo`<0i^KV=03oool30820P0<0
i^KV5P3oool20>KViSX0oooo0@0000010?ooo`0000<000000?ooo`3oool0S03oool30>KViS@0oooo
0`20P8030>KViQH0oooo0P3Vi^Hj0?ooo`4000000@3oool000030000003oool0oooo08`0oooo0`3V
i^Hd0?ooo`<0P8200`3Vi^HF0?ooo`80i^KV>P3oool100000040oooo00000`000000oooo0?ooo`1^
0?ooo`<0i^KV=03oool30>KViQH0oooo0`3Vi^H20820P3@0oooo0`3Vi^HQ0?ooo`4000000@3oool0
00030000003oool0oooo06h0oooo0`3Vi^Hd0?ooo`<0i^KV5P3oool30>KViP80P820=03oool30>KV
iR40oooo0@0000010?ooo`0000<000000?ooo`3oool0KP3oool30>KViS@0oooo0`3Vi^HF0?ooo`<0
i^KV0P20P80d0?ooo`<0i^KV8@3oool100000040oooo00000`000000oooo0?ooo`1/0?ooo`80i^KV
=03oool30>KViQ40oooo0P3Vi^H30?ooo`<0i^KV0`0000020>KViS80oooo0P3Vi^HT0?ooo`400000
0@3oool000030000003oool0oooo06`0oooo0P3Vi^Hd0?ooo`<0i^KV4@3oool20>KViP<0oooo0`3V
i^H300000080i^KV<P3oool20>KViR@0oooo0@0000010?ooo`0000<000000?ooo`3oool0K03oool2
0>KViS@0oooo0`3Vi^HA0?ooo`80i^KV0`3oool30>KViP<000000P3Vi^Hb0?ooo`80i^KV903oool1
00000040oooo00000`000000oooo0?ooo`1Y0?ooo`<0i^KV=03oool20>KViQ40oooo0`3Vi^H20?oo
o`<0i^KV0`0000030>KViS40oooo0`3Vi^HV0?ooo`4000000@3oool000030000003oool0oooo06T0
oooo0`3Vi^Hd0?ooo`80i^KV4@3oool30>KViP80oooo0`3Vi^H3000000<0i^KV<@3oool30>KViRH0
oooo0@0000010?ooo`0000<000000?ooo`3oool0IP3oool30>KViS@0oooo0`3Vi^H@0?ooo`<0i^KV
1@3oool30820P0<0i^KV<@3oool30>KViRT0oooo0@0000010?ooo`0000<000000?ooo`3oool0IP3o
ool30>KViS@0oooo0`3Vi^H@0?ooo`<0i^KV1@3oool30820P0<0i^KV<@3oool30>KViRT0oooo0@00
00010?ooo`0000<000000?ooo`3oool0IP3oool30>KViS@0oooo0`3Vi^H@0?ooo`<0i^KV1@3oool3
0820P0<0i^KV<@3oool30>KViRT0oooo0@0000010?ooo`0000<000000?ooo`3oool0H`3oool30>KV
iS@0oooo0`3Vi^HF0?ooo`<0i^KV0P20P8060?ooo`<0i^KV:`3oool30>KViR`0oooo0@0000010?oo
o`0000<000000?ooo`3oool0H`3oool30>KViS@0oooo0`3Vi^HF0?ooo`<0i^KV0P20P8060?ooo`<0
i^KV:`3oool30>KViR`0oooo0@0000010?ooo`0000<000000?ooo`3oool0H`3oool30>KViS@0oooo
0`3Vi^HF0?ooo`<0i^KV0P20P8060?ooo`<0i^KV:`3oool30>KViR`0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0H@3oool20>KViS@0oooo0`3Vi^HC0?ooo`H0i^KV0`20P8020>KViP<0oooo0`3V
i^H/0?ooo`80i^KV;`3oool100000040oooo00000`000000oooo0?ooo`1Q0?ooo`80i^KV=03oool3
0>KViQ<0oooo1P3Vi^H30820P080i^KV0`3oool30>KViR`0oooo0P3Vi^H_0?ooo`4000000@3oool0
00030000003oool0oooo05h0oooo0`3Vi^Hd0?ooo`80i^KV503oool20>KViPH0oooo0`3Vi^H20?oo
o`<0i^KV;03oool30>KViS40oooo0@0000010?ooo`0000<000000?ooo`3oool0GP3oool30>KViS@0
oooo0P3Vi^HD0?ooo`80i^KV1P3oool30>KViP80oooo0`3Vi^H/0?ooo`<0i^KV<@3oool100000040
oooo00000`000000oooo0?ooo`1N0?ooo`<0i^KV=03oool20>KViQ@0oooo0P3Vi^H60?ooo`<0i^KV
0P3oool30>KViR`0oooo0`3Vi^Ha0?ooo`4000000@3oool000030000003oool0oooo05/0oooo0`3V
i^Hd0?ooo`<0i^KV5P3oool20>KViP<000000`3oool30>KViRh0oooo0`3Vi^Hd0?ooo`4000000@3o
ool000030000003oool0oooo05/0oooo0`3Vi^Hd0?ooo`<0i^KV5P3oool20>KViP<000000`3oool3
0>KViRh0oooo0`3Vi^Hd0?ooo`4000000@3oool000030000003oool0oooo05/0oooo0`3Vi^Hd0?oo
o`<0i^KV5P3oool20>KViP<000000`3oool30>KViRh0oooo0`3Vi^Hd0?ooo`4000000@3oool00003
0000003oool0oooo05P0oooo0`3Vi^Hd0?ooo`<0i^KV5P3oool30>KViP80P8201P3Vi^H^0?ooo`<0
i^KV=`3oool100000040oooo00000`000000oooo0?ooo`1H0?ooo`<0i^KV=03oool30>KViQH0oooo
0`3Vi^H20820P0H0i^KV;P3oool30>KViSL0oooo0@0000010?ooo`0000<000000?ooo`3oool0F03o
ool30>KViS@0oooo0`3Vi^HF0?ooo`<0i^KV0P20P8060>KViRh0oooo0`3Vi^Hg0?ooo`4000000@3o
ool000030000003oool0oooo05H0oooo0P3Vi^Hd0?ooo`<0i^KV6@3oool30820P080i^KV<P3oool2
0>KViSX0oooo0@0000010?ooo`0000<000000?ooo`3oool0EP3oool20>KViS@0oooo0`3Vi^HI0?oo
o`<0P8200P3Vi^Hb0?ooo`80i^KV>P3oool100000040oooo00000`000000oooo0?ooo`1C0?ooo`<0
i^KV=03oool20>KViQH0oooo0`3Vi^H30820P1T0oooo0P3Vi^HI0?ooo`<0i^KV?03oool100000040
oooo00000`000000oooo0?ooo`1C0?ooo`<0i^KV=03oool20>KViQH0oooo0`3Vi^H30820P1T0oooo
0P3Vi^HI0?ooo`<0i^KV?03oool100000040oooo00000`000000oooo0?ooo`1C0?ooo`<0i^KV=03o
ool20>KViQH0oooo0`3Vi^H30820P1T0oooo0P3Vi^HI0?ooo`<0i^KV?03oool100000040oooo0000
0`000000oooo0?ooo`1@0?ooo`<0i^KV=03oool30>KViQ00oooo0`3Vi^H30?ooo`80i^KV0`000003
0>KViQH0oooo0`3Vi^HH0?ooo`<0i^KV?`3oool100000040oooo00000`000000oooo0?ooo`1@0?oo
o`<0i^KV=03oool30>KViQ00oooo0`3Vi^H30?ooo`80i^KV0`0000030>KViQH0oooo0`3Vi^HH0?oo
o`<0i^KV?`3oool100000040oooo00000`000000oooo0?ooo`1@0?ooo`<0i^KV=03oool30>KViQ00
oooo0`3Vi^H30?ooo`80i^KV0`0000030>KViQH0oooo0`3Vi^HH0?ooo`<0i^KV?`3oool100000040
oooo00000`000000oooo0?ooo`1=0?ooo`<0i^KV=03oool30>KViQ00oooo0`3Vi^H30?ooo`<0i^KV
0P20P8030>KViQH0oooo0`3Vi^HH0?ooo`<0i^KV@P3oool100000040oooo00000`000000oooo0?oo
o`1=0?ooo`<0i^KV=03oool30>KViQ00oooo0`3Vi^H30?ooo`<0i^KV0P20P8030>KViQH0oooo0`3V
i^HH0?ooo`<0i^KV@P3oool100000040oooo00000`000000oooo0?ooo`1;0?ooo`80i^KV=@3oool2
0>KViQ40oooo0P3Vi^H60?ooo`<000000P3Vi^HF0?ooo`<0i^KV6@3oool20>KViTD0oooo0@000001
0?ooo`0000<000000?ooo`3oool0B`3oool20>KViSD0oooo0P3Vi^HA0?ooo`80i^KV1P3oool30000
0080i^KV5P3oool30>KViQT0oooo0P3Vi^I50?ooo`4000000@3oool000030000003oool0oooo04/0
oooo0P3Vi^He0?ooo`80i^KV4@3oool20>KViPH0oooo0`0000020>KViQH0oooo0`3Vi^HI0?ooo`80
i^KVA@3oool100000040oooo00000`000000oooo0?ooo`180?ooo`<0i^KV=03oool30>KViQD0oooo
0`3Vi^H30820P0D0oooo0`3Vi^HA0?ooo`80i^KV6@3oool30>KViTL0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0B03oool30>KViS@0oooo0`3Vi^HE0?ooo`<0i^KV0`20P8050?ooo`<0i^KV4@3o
ool20>KViQT0oooo0`3Vi^I70?ooo`4000000@3oool000030000003oool0oooo04P0oooo0`3Vi^Hd
0?ooo`<0i^KV5@3oool30>KViP<0P8201@3oool30>KViQ40oooo0P3Vi^HI0?ooo`<0i^KVA`3oool1
00000040oooo00000`000000oooo0?ooo`150?ooo`<0i^KV=03oool30>KViQ<0oooo1@3Vi^H30?oo
o`<0i^KV0`3oool20>KViQ40oooo0`3Vi^HH0?ooo`<0i^KVBP3oool100000040oooo00000`000000
oooo0?ooo`150?ooo`<0i^KV=03oool30>KViQ<0oooo1@3Vi^H30?ooo`<0i^KV0`3oool20>KViQ40
oooo0`3Vi^HH0?ooo`<0i^KVBP3oool100000040oooo00000`000000oooo0?ooo`150?ooo`<0i^KV
=03oool30>KViQ<0oooo1@3Vi^H30?ooo`<0i^KV0`3oool20>KViQ40oooo0`3Vi^HH0?ooo`<0i^KV
BP3oool100000040oooo00000`000000oooo0?ooo`120?ooo`<0i^KV=03oool30>KViQ<0oooo0`3V
i^H30?ooo`80P8200`3Vi^H30?ooo`<0i^KV403oool30>KViQT0oooo0P3Vi^I=0?ooo`4000000@3o
ool000030000003oool0oooo0480oooo0`3Vi^Hd0?ooo`<0i^KV4`3oool30>KViP<0oooo0P20P803
0>KViP<0oooo0`3Vi^H@0?ooo`<0i^KV6@3oool20>KViTd0oooo0@0000010?ooo`0000<000000?oo
o`3oool0@03oool20>KViSD0oooo0P3Vi^HF0?ooo`<0i^KV0`20P8020?ooo`<0i^KV4`3oool30>KV
iQT0oooo0`3Vi^I?0?ooo`4000000@3oool000030000003oool0oooo0400oooo0P3Vi^He0?ooo`80
i^KV5P3oool30>KViP<0P8200P3oool30>KViQ<0oooo0`3Vi^HI0?ooo`<0i^KVC`3oool100000040
oooo00000`000000oooo0?ooo`100?ooo`80i^KV=@3oool20>KViQH0oooo0`3Vi^H30820P080oooo
0`3Vi^HC0?ooo`<0i^KV6@3oool30>KViTl0oooo0@0000010?ooo`0000<000000?ooo`3oool0?@3o
ool30>KViS@0oooo0`3Vi^HE0?ooo`<0i^KV0`0000050>KViQ@0oooo0P3Vi^HI0?ooo`<0i^KVDP3o
ool100000040oooo00000`000000oooo0?ooo`0m0?ooo`<0i^KV=03oool30>KViQD0oooo0`3Vi^H3
000000D0i^KV503oool20>KViQT0oooo0`3Vi^IB0?ooo`4000000@3oool000030000003oool0oooo
03d0oooo0`3Vi^Hd0?ooo`<0i^KV5@3oool30>KViP<000001@3Vi^HD0?ooo`80i^KV6@3oool30>KV
iU80oooo0@0000010?ooo`0000<000000?ooo`3oool0>P3oool30>KViS@0oooo0`3Vi^HH0?ooo`<0
P8200`3Vi^HF0?ooo`<0i^KV603oool30>KViUD0oooo0@0000010?ooo`0000<000000?ooo`3oool0
>P3oool30>KViS@0oooo0`3Vi^HH0?ooo`<0P8200`3Vi^HF0?ooo`<0i^KV603oool30>KViUD0oooo
0@0000010?ooo`0000<000000?ooo`3oool0>P3oool30>KViS@0oooo0`3Vi^HH0?ooo`<0P8200`3V
i^HF0?ooo`<0i^KV603oool30>KViUD0oooo0@0000010?ooo`0000<000000?ooo`3oool0>03oool2
0>KViTd0oooo0`3Vi^H20820P1T0oooo0`3Vi^Ic0?ooo`4000000@3oool000030000003oool0oooo
03P0oooo0P3Vi^I=0?ooo`<0i^KV0P20P80I0?ooo`<0i^KVL`3oool100000040oooo00000`000000
oooo0?ooo`0e0?ooo`<0i^KVA`3oool30>KViP80oooo0`3Vi^H30820P080i^KV5P3oool30>KViWH0
oooo0@0000010?ooo`0000<000000?ooo`3oool0=@3oool30>KViTL0oooo0`3Vi^H20?ooo`<0i^KV
0`20P8020>KViQH0oooo0`3Vi^If0?ooo`4000000@3oool000030000003oool0oooo03D0oooo0`3V
i^I70?ooo`<0i^KV0P3oool30>KViP<0P8200P3Vi^HF0?ooo`<0i^KVMP3oool100000040oooo0000
0`000000oooo0?ooo`0b0?ooo`<0i^KVA`3oool30>KViP<0oooo0P3Vi^H3000000<0i^KV5P3oool2
0>KViWT0oooo0@0000010?ooo`0000<000000?ooo`3oool0<P3oool30>KViTL0oooo0`3Vi^H30?oo
o`80i^KV0`0000030>KViQH0oooo0P3Vi^Ii0?ooo`4000000@3oool000030000003oool0oooo0380
oooo0`3Vi^I70?ooo`<0i^KV0`3oool20>KViP<000000`3Vi^HF0?ooo`80i^KVN@3oool100000040
oooo00000`000000oooo0?ooo`0_0?ooo`<0i^KVA`3oool30>KViPH0oooo0P0000030>KViQH0oooo
0`3Vi^Ik0?ooo`4000000@3oool000030000003oool0oooo02l0oooo0`3Vi^I70?ooo`<0i^KV1P3o
ool2000000<0i^KV5P3oool30>KViW/0oooo0@0000010?ooo`0000<000000?ooo`3oool0;@3oool2
0>KViTd0oooo0`3Vi^H80?ooo`<0i^KV403oool30>KViWh0oooo0@0000010?ooo`0000<000000?oo
o`3oool0;@3oool20>KViTd0oooo0`3Vi^H80?ooo`<0i^KV403oool30>KViWh0oooo0@0000010?oo
o`0000<000000?ooo`3oool0;@3oool20>KViTd0oooo0`3Vi^H80?ooo`<0i^KV403oool30>KViWh0
oooo0@0000010?ooo`0000<000000?ooo`3oool0:P3oool30>KViTX0oooo1@3Vi^H30820P0<0i^KV
0P3oool30>KViQ00oooo0`3Vi^J10?ooo`4000000@3oool000030000003oool0oooo02X0oooo0`3V
i^I:0?ooo`D0i^KV0`20P8030>KViP80oooo0`3Vi^H@0?ooo`<0i^KVP@3oool100000040oooo0000
0`000000oooo0?ooo`0Z0?ooo`<0i^KVBP3oool50>KViP<0P8200`3Vi^H20?ooo`<0i^KV403oool3
0>KViX40oooo0@0000010?ooo`0000<000000?ooo`3oool09`3oool30>KViTX0oooo0`3Vi^H20?oo
o`<0P8200`3Vi^H30?ooo`80i^KV4@3oool20>KViX@0oooo0@0000010?ooo`0000<000000?ooo`3o
ool09`3oool30>KViTX0oooo0`3Vi^H20?ooo`<0P8200`3Vi^H30?ooo`80i^KV4@3oool20>KViX@0
oooo0@0000010?ooo`0000<000000?ooo`3oool09`3oool30>KViTX0oooo0`3Vi^H20?ooo`<0P820
0`3Vi^H30?ooo`80i^KV4@3oool20>KViX@0oooo0@0000010?ooo`0000<000000?ooo`3oool0903o
ool30>KViTd0oooo0`3Vi^H20820P0<0oooo0`3Vi^HC0?ooo`<0i^KVQP3oool100000040oooo0000
0`000000oooo0?ooo`0T0?ooo`<0i^KVC@3oool30>KViP80P8200`3oool30>KViQ<0oooo0`3Vi^J6
0?ooo`4000000@3oool000030000003oool0oooo0280oooo0P3Vi^I=0?ooo`<0i^KV0`20P8050>KV
iQ<0oooo0`3Vi^J90?ooo`4000000@3oool000030000003oool0oooo0280oooo0P3Vi^I=0?ooo`<0
i^KV0`20P8050>KViQ<0oooo0`3Vi^J90?ooo`4000000@3oool000030000003oool0oooo0280oooo
0P3Vi^I=0?ooo`<0i^KV0`20P8050>KViQ<0oooo0`3Vi^J90?ooo`4000000@3oool000030000003o
ool0oooo01l0oooo0`3Vi^I?0?ooo`<000000`3Vi^HE0?ooo`<0i^KVS03oool100000040oooo0000
0`000000oooo0?ooo`0O0?ooo`<0i^KVC`3oool3000000<0i^KV5@3oool30>KViX`0oooo0@000001
0?ooo`0000<000000?ooo`3oool07`3oool30>KViTl0oooo0`0000030>KViQD0oooo0`3Vi^J<0?oo
o`4000000@3oool000030000003oool0oooo05<0oooo0`3Vi^HF0?ooo`80i^KV0`20P81@0?ooo`80
i^KVF03oool100000040oooo00000`000000oooo0?ooo`1C0?ooo`<0i^KV5P3oool20>KViP<0P820
D03oool20>KViUP0oooo0@0000010?ooo`0000<000000?ooo`3oool0D03oool30>KViQ00oooo0`3V
i^H30?ooo`<0i^KV0P20P8030>KViTd0oooo0`3Vi^IJ0?ooo`4000000@3oool000030000003oool0
oooo0500oooo0`3Vi^H@0?ooo`<0i^KV0`3oool30>KViP80P8200`3Vi^I=0?ooo`<0i^KVFP3oool1
00000040oooo00000`000000oooo0?ooo`1@0?ooo`<0i^KV403oool30>KViP<0oooo0`3Vi^H20820
P0<0i^KVC@3oool30>KViUX0oooo0@0000010?ooo`0000<000000?ooo`3oool0C@3oool30>KViQ40
oooo0P3Vi^H30?ooo`<0i^KV0`20P8020>KViTd0oooo0`3Vi^IM0?ooo`4000000@3oool000030000
003oool0oooo04d0oooo0`3Vi^HA0?ooo`80i^KV0`3oool30>KViP<0P8200P3Vi^I=0?ooo`<0i^KV
G@3oool100000040oooo00000`000000oooo0?ooo`1=0?ooo`<0i^KV4@3oool20>KViP<0oooo0`3V
i^H30820P080i^KVC@3oool30>KViUd0oooo0@0000010?ooo`0000<000000?ooo`3oool0B`3oool2
0>KViQ40oooo0`3Vi^H80?ooo`<0i^KVC03oool30>KViV00oooo0@0000010?ooo`0000<000000?oo
o`3oool0B`3oool20>KViQ40oooo0`3Vi^H80?ooo`<0i^KVC03oool30>KViV00oooo0@0000010?oo
o`0000<000000?ooo`3oool0B`3oool20>KViQ40oooo0`3Vi^H80?ooo`<0i^KVC03oool30>KViV00
oooo0@0000010?ooo`0000<000000?ooo`3oool0B03oool30>KViQH0oooo0P3Vi^H3000000H0oooo
0P3Vi^I80?ooo`80i^KVH`3oool100000040oooo00000`000000oooo0?ooo`180?ooo`<0i^KV5P3o
ool20>KViP<000001P3oool20>KViTP0oooo0P3Vi^IS0?ooo`4000000@3oool000030000003oool0
oooo04D0oooo0`3Vi^HC0?ooo`H0i^KV0P0000030>KViP<0oooo0`3Vi^I70?ooo`<0i^KVI@3oool1
00000040oooo00000`000000oooo0?ooo`150?ooo`<0i^KV4`3oool60>KViP8000000`3Vi^H30?oo
o`<0i^KVA`3oool30>KViVD0oooo0@0000010?ooo`0000<000000?ooo`3oool0A@3oool30>KViQ<0
oooo1P3Vi^H2000000<0i^KV0`3oool30>KViTL0oooo0`3Vi^IU0?ooo`4000000@3oool000030000
003oool0oooo0480oooo0`3Vi^HC0?ooo`<0i^KV0`3oool30820P080i^KV0`3oool30>KViTL0oooo
0`3Vi^IX0?ooo`4000000@3oool000030000003oool0oooo0480oooo0`3Vi^HC0?ooo`<0i^KV0`3o
ool30820P080i^KV0`3oool30>KViTL0oooo0`3Vi^IX0?ooo`4000000@3oool000030000003oool0
oooo0480oooo0`3Vi^HC0?ooo`<0i^KV0`3oool30820P080i^KV0`3oool30>KViTL0oooo0`3Vi^IX
0?ooo`4000000@3oool000030000003oool0oooo0400oooo0P3Vi^HF0?ooo`<0i^KV0`0000030?oo
o`80i^KVBP3oool30>KViV/0oooo0@0000010?ooo`0000<000000?ooo`3oool0@03oool20>KViQH0
oooo0`3Vi^H3000000<0oooo0P3Vi^I:0?ooo`<0i^KVJ`3oool100000040oooo00000`000000oooo
0?ooo`100?ooo`80i^KV5P3oool30>KViP<000000`3oool20>KViTX0oooo0`3Vi^I[0?ooo`400000
0@3oool000030000003oool0oooo03d0oooo0`3Vi^HF0?ooo`80i^KV0`20P8060>KViTX0oooo0P3V
i^I^0?ooo`4000000@3oool000030000003oool0oooo03d0oooo0`3Vi^HF0?ooo`80i^KV0`20P806
0>KViTX0oooo0P3Vi^I^0?ooo`4000000@3oool000030000003oool0oooo03X0oooo0`3Vi^HI0?oo
o`80P8200`3Vi^I=0?ooo`<0i^KVL03oool100000040oooo00000`000000oooo0?ooo`0j0?ooo`<0
i^KV6@3oool20820P0<0i^KVC@3oool30>KViW00oooo0@0000010?ooo`0000<000000?ooo`3oool0
>P3oool30>KViQT0oooo0P20P8030>KViTd0oooo0`3Vi^I`0?ooo`4000000@3oool000030000003o
ool0oooo03P0oooo0P3Vi^HF0?ooo`<0i^KV0`20P80H0?ooo`<0i^KV=03oool30>KViW<0oooo0@00
00010?ooo`0000<000000?ooo`3oool0>03oool20>KViQH0oooo0`3Vi^H30820P1P0oooo0`3Vi^Hd
0?ooo`<0i^KVL`3oool100000040oooo00000`000000oooo0?ooo`0h0?ooo`80i^KV5P3oool30>KV
iP<0P820603oool30>KViS@0oooo0`3Vi^Ic0?ooo`4000000@3oool000030000003oool0oooo03D0
oooo0`3Vi^H@0?ooo`<0i^KV0P3oool30>KViP<0P8200`3Vi^HF0?ooo`80i^KV=03oool30>KViWH0
oooo0@0000010?ooo`0000<000000?ooo`3oool0=@3oool30>KViQ00oooo0`3Vi^H20?ooo`<0i^KV
0`20P8030>KViQH0oooo0P3Vi^Hd0?ooo`<0i^KVMP3oool100000040oooo00000`000000oooo0?oo
o`0b0?ooo`<0i^KV403oool30>KViP<0oooo0P3Vi^H30?ooo`<0i^KV5P3oool30>KViS@0oooo0P3V
i^Ii0?ooo`4000000@3oool000030000003oool0oooo0380oooo0`3Vi^H@0?ooo`<0i^KV0`3oool2
0>KViP<0oooo0`3Vi^HF0?ooo`<0i^KV=03oool20>KViWT0oooo0@0000010?ooo`0000<000000?oo
o`3oool0<P3oool30>KViQ00oooo0`3Vi^H30?ooo`80i^KV0`3oool30>KViQH0oooo0`3Vi^Hd0?oo
o`80i^KVN@3oool100000040oooo00000`000000oooo0?ooo`0_0?ooo`<0i^KV403oool30>KViPH0
oooo0P20P8030>KViQH0oooo0`3Vi^Hd0?ooo`<0i^KVN`3oool100000040oooo00000`000000oooo
0?ooo`0_0?ooo`<0i^KV403oool30>KViPH0oooo0P20P8030>KViQH0oooo0`3Vi^Hd0?ooo`<0i^KV
N`3oool100000040oooo00000`000000oooo0?ooo`0_0?ooo`<0i^KV403oool30>KViPH0oooo0P20
P8030>KViQH0oooo0`3Vi^Hd0?ooo`<0i^KVN`3oool100000040oooo00000`000000oooo0?ooo`0]
0?ooo`80i^KV5P3oool30>KViP<000001@3oool30>KViQ00oooo0`3Vi^Hd0?ooo`<0i^KVOP3oool1
00000040oooo00000`000000oooo0?ooo`0]0?ooo`80i^KV5P3oool30>KViP<000001@3oool30>KV
iQ00oooo0`3Vi^Hd0?ooo`<0i^KVOP3oool100000040oooo00000`000000oooo0?ooo`0]0?ooo`80
i^KV5P3oool30>KViP<000001@3oool30>KViQ00oooo0`3Vi^Hd0?ooo`<0i^KVOP3oool100000040
oooo00000`000000oooo0?ooo`0Z0?ooo`<0i^KV4`3oool50>KViP<0P8200`3Vi^H20?ooo`<0i^KV
4@3oool20>KViS@0oooo0`3Vi^J10?ooo`4000000@3oool000030000003oool0oooo02X0oooo0`3V
i^HC0?ooo`D0i^KV0`20P8030>KViP80oooo0`3Vi^HA0?ooo`80i^KV=03oool30>KViX40oooo0@00
00010?ooo`0000<000000?ooo`3oool09`3oool30>KViQ<0oooo0`3Vi^H20?ooo`<000000`3Vi^H3
0?ooo`80i^KV4@3oool30>KViS@0oooo0P3Vi^J40?ooo`4000000@3oool000030000003oool0oooo
02L0oooo0`3Vi^HC0?ooo`<0i^KV0P3oool3000000<0i^KV0`3oool20>KViQ40oooo0`3Vi^Hd0?oo
o`80i^KVQ03oool100000040oooo00000`000000oooo0?ooo`0W0?ooo`<0i^KV4`3oool30>KViP80
oooo0`0000030>KViP<0oooo0P3Vi^HA0?ooo`<0i^KV=03oool20>KViX@0oooo0@0000010?ooo`00
00<000000?ooo`3oool0903oool30>KViQH0oooo0`3Vi^H20820P0<0oooo0`3Vi^HC0?ooo`<0i^KV
=03oool30>KViXH0oooo0@0000010?ooo`0000<000000?ooo`3oool0903oool30>KViQH0oooo0`3V
i^H20820P0<0oooo0`3Vi^HC0?ooo`<0i^KV=03oool30>KViXH0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0903oool30>KViQH0oooo0`3Vi^H20820P0<0oooo0`3Vi^HC0?ooo`<0i^KV=03oool3
0>KViXH0oooo0@0000010?ooo`0000<000000?ooo`3oool08P3oool20>KViQH0oooo0`3Vi^H30000
00D0i^KV4`3oool30>KViS@0oooo0`3Vi^J90?ooo`4000000@3oool000030000003oool0oooo0280
oooo0P3Vi^HF0?ooo`<0i^KV0`0000050>KViQ<0oooo0`3Vi^Hd0?ooo`<0i^KVR@3oool100000040
oooo00000`000000oooo0?ooo`0O0?ooo`<0i^KV603oool30820P0<0i^KV5P3oool20>KViS@0oooo
0`3Vi^J<0?ooo`4000000@3oool000030000003oool0oooo01l0oooo0`3Vi^HH0?ooo`<0P8200`3V
i^HF0?ooo`80i^KV=03oool30>KViX`0oooo0@0000010?ooo`0000<000000?ooo`3oool07`3oool3
0>KViQP0oooo0`20P8030>KViQH0oooo0P3Vi^Hd0?ooo`<0i^KVS03oool100000040oooo00000`00
0000oooo0?ooo`0L0?ooo`<0i^KV5P3oool30>KViP80P8206@3oool30>KViS@0oooo0P3Vi^J?0?oo
o`4000000@3oool000030000003oool0oooo01`0oooo0`3Vi^HF0?ooo`<0i^KV0P20P80I0?ooo`<0
i^KV=03oool20>KViXl0oooo0@0000010?ooo`0000<000000?ooo`3oool0703oool30>KViQH0oooo
0`3Vi^H20820P1T0oooo0`3Vi^Hd0?ooo`80i^KVS`3oool100000040oooo00000`000000oooo0?oo
o`0I0?ooo`<0i^KV4@3oool20>KViP<0oooo0`3Vi^H30?ooo`80i^KV5P3oool30>KViS@0oooo0`3V
i^JA0?ooo`4000000@3oool000030000003oool0oooo01T0oooo0`3Vi^HA0?ooo`80i^KV0`3oool3
0>KViP<0oooo0P3Vi^HF0?ooo`<0i^KV=03oool30>KViY40oooo0@0000010?ooo`0000<000000?oo
o`3oool06@3oool30>KViQ40oooo0P3Vi^H30?ooo`<0i^KV0`3oool20>KViQH0oooo0`3Vi^Hd0?oo
o`<0i^KVT@3oool100000040oooo00000`000000oooo0?ooo`0G0?ooo`80i^KV4@3oool30>KViP80
oooo0`3Vi^H30820P0<0i^KV5@3oool30>KViS@0oooo0`3Vi^JD0?ooo`4000000@3oool000030000
003oool0oooo01L0oooo0P3Vi^HA0?ooo`<0i^KV0P3oool30>KViP<0P8200`3Vi^HE0?ooo`<0i^KV
=03oool30>KViY@0oooo0@0000010?ooo`0000<000000?ooo`3oool0503oool30>KViQ00oooo0`3V
i^H50?ooo`<0P8200`3Vi^HF0?ooo`80i^KV=@3oool20>KViYL0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0503oool30>KViQ00oooo0`3Vi^H50?ooo`<0P8200`3Vi^HF0?ooo`80i^KV=@3oool2
0>KViYL0oooo0@0000010?ooo`0000<000000?ooo`3oool0503oool30>KViQ00oooo0`3Vi^H50?oo
o`<0P8200`3Vi^HF0?ooo`80i^KV=@3oool20>KViYL0oooo0@0000010?ooo`0000<000000?ooo`3o
ool04@3oool30>KViQH0oooo0`3Vi^H20820P0H0oooo0`3Vi^H@0?ooo`<0i^KV=03oool30>KViYT0
oooo0@0000010?ooo`0000<000000?ooo`3oool04@3oool30>KViQH0oooo0`3Vi^H20820P0H0oooo
0`3Vi^H@0?ooo`<0i^KV=03oool30>KViYT0oooo0@0000010?ooo`0000<000000?ooo`3oool04@3o
ool30>KViQH0oooo0`3Vi^H20820P0H0oooo0`3Vi^H@0?ooo`<0i^KV=03oool30>KViYT0oooo0@00
00010?ooo`0000<000000?ooo`3oool03P3oool30>KViQ<0oooo1P3Vi^H300000080i^KV0`3oool3
0>KViQ00oooo0`3Vi^Hd0?ooo`<0i^KVW03oool100000040oooo00000`000000oooo0?ooo`0>0?oo
o`<0i^KV4`3oool60>KViP<000000P3Vi^H30?ooo`<0i^KV403oool30>KViS@0oooo0`3Vi^JL0?oo
o`4000000@3oool000030000003oool0oooo00`0oooo0P3Vi^HD0?ooo`80i^KV0`3oool3000000<0
i^KV0P3oool30>KViQ00oooo0`3Vi^Hd0?ooo`<0i^KVW`3oool100000040oooo00000`000000oooo
0?ooo`0<0?ooo`80i^KV503oool20>KViP<0oooo0`0000030>KViP80oooo0`3Vi^H@0?ooo`<0i^KV
=03oool30>KViYl0oooo0@0000010?ooo`0000<000000?ooo`3oool0303oool20>KViQ@0oooo0P3V
i^H30?ooo`<000000`3Vi^H20?ooo`<0i^KV403oool30>KViS@0oooo0`3Vi^JO0?ooo`4000000@3o
ool000030000003oool0oooo00T0oooo0`3Vi^HF0?ooo`80i^KV0`20P8030?ooo`<0i^KV4`3oool2
0>KViSD0oooo0P3Vi^JR0?ooo`4000000@3oool000030000003oool0oooo00T0oooo0`3Vi^HF0?oo
o`80i^KV0`20P8030?ooo`<0i^KV4`3oool20>KViSD0oooo0P3Vi^JR0?ooo`4000000@3oool00003
0000003oool0oooo00T0oooo0`3Vi^HF0?ooo`80i^KV0`20P8030?ooo`<0i^KV4`3oool20>KViSD0
oooo0P3Vi^JR0?ooo`4000000@3oool000030000003oool0oooo00H0oooo0`3Vi^HF0?ooo`<0i^KV
0P20P8060>KViQ<0oooo0`3Vi^Hd0?ooo`<0i^KVY03oool100000040oooo00000`000000oooo0?oo
o`060?ooo`<0i^KV5P3oool30>KViP80P8201P3Vi^HC0?ooo`<0i^KV=03oool30>KViZ@0oooo0@00
00010?ooo`0000<000000?ooo`3oool01P3oool30>KViQH0oooo0`3Vi^H20820P0H0i^KV4`3oool3
0>KViS@0oooo0`3Vi^JT0?ooo`4000000@3oool000030000003oool0oooo00<0oooo0`3Vi^HI0?oo
o`<000000P3Vi^HF0?ooo`<0i^KV=03oool30>KViZL0oooo0@0000010?ooo`0000<000000?ooo`3o
ool00`3oool30>KViQT0oooo0`0000020>KViQH0oooo0`3Vi^Hd0?ooo`<0i^KVY`3oool100000040
oooo00000`000000oooo0?ooo`0I0?ooo`<0i^KV703oool20>KVi^40oooo0@0000010?ooo`0000<0
00000?ooo`3oool06@3oool30>KViQ`0oooo0P3Vi^KQ0?ooo`4000000@3oool000030000003oool0
oooo01T0oooo0`3Vi^HL0?ooo`80i^KVh@3oool100000040oooo00000`000000oooo0?ooo`0A0?oo
o`<0i^KV0`3oool20>KViP<0P8200`3Vi^HF0?ooo`<0i^KVh`3oool100000040oooo00000`000000
oooo0?ooo`0A0?ooo`<0i^KV0`3oool20>KViP<0P8200`3Vi^HF0?ooo`<0i^KVh`3oool100000040
oooo00000`000000oooo0?ooo`0A0?ooo`<0i^KV0`3oool20>KViP<0P8200`3Vi^HF0?ooo`<0i^KV
h`3oool100000040oooo00000`000000oooo0?ooo`0>0?ooo`<0i^KV0`3oool30>KViP80P8200`3V
i^HF0?ooo`<0i^KViP3oool100000040oooo00000`000000oooo0?ooo`0>0?ooo`<0i^KV0`3oool3
0>KViP80P8200`3Vi^HF0?ooo`<0i^KViP3oool100000040oooo00000`000000oooo0?ooo`0>0?oo
o`<0i^KV0`3oool30>KViP80P8200`3Vi^HF0?ooo`<0i^KViP3oool100000040oooo00000`000000
oooo0?ooo`0<0?ooo`80i^KV1P3oool30820P080i^KV5P3oool30>KVi^T0oooo0@0000010?ooo`00
00<000000?ooo`3oool0303oool20>KViPH0oooo0`20P8020>KViQH0oooo0`3Vi^KY0?ooo`400000
0@3oool000030000003oool0oooo00h0oooo0`3Vi^H30820P0D0oooo0`3Vi^HA0?ooo`80i^KVk03o
ool100000040oooo00000`000000oooo0?ooo`0>0?ooo`<0i^KV0`20P8050?ooo`<0i^KV4@3oool2
0>KVi^`0oooo0@0000010?ooo`0000<000000?ooo`3oool03P3oool30>KViP<0P8201@3oool30>KV
iQ40oooo0P3Vi^K/0?ooo`4000000@3oool000030000003oool0oooo00T0oooo1@3Vi^H30820P0<0
i^KV0`3oool20>KViQ40oooo0`3Vi^K^0?ooo`4000000@3oool000030000003oool0oooo00T0oooo
1@3Vi^H30820P0<0i^KV0`3oool20>KViQ40oooo0`3Vi^K^0?ooo`4000000@3oool000030000003o
ool0oooo00T0oooo1@3Vi^H30820P0<0i^KV0`3oool20>KViQ40oooo0`3Vi^K^0?ooo`4000000@3o
ool000030000003oool0oooo00H0oooo0`3Vi^H30?ooo`80P8200`3Vi^H30?ooo`<0i^KV403oool3
0>KVi_40oooo0@0000010?ooo`0000<000000?ooo`3oool01P3oool30>KViP<0oooo0P20P8030>KV
iP<0oooo0`3Vi^H@0?ooo`<0i^KVl@3oool100000040oooo00000`000000oooo0?ooo`060?ooo`<0
i^KV0`0000020?ooo`<0i^KV4`3oool30>KVi_@0oooo0@0000010?ooo`0000<000000?ooo`3oool0
1P3oool30>KViP<000000P3oool30>KViQ<0oooo0`3Vi^Kd0?ooo`4000000@3oool000030000003o
ool0oooo00H0oooo0`3Vi^H300000080oooo0`3Vi^HC0?ooo`<0i^KVm03oool100000040oooo0000
0`000000oooo0?ooo`030?ooo`<0i^KV0`0000050>KViQ@0oooo0P3Vi^Kg0?ooo`4000000@3oool0
00030000003oool0oooo00<0oooo0`3Vi^H3000000D0i^KV503oool20>KVi_L0oooo0@0000010?oo
o`0000<000000?ooo`3oool00`3oool30>KViP<000001@3Vi^HD0?ooo`80i^KVm`3oool100000040
oooo00000`000000oooo0?ooo`030?ooo`<000000`3Vi^HF0?ooo`<0i^KVn@3oool100000040oooo
00000`000000oooo0?ooo`030?ooo`<000000`3Vi^HF0?ooo`<0i^KVn@3oool100000040oooo0000
0`000000oooo0?ooo`030?ooo`<000000`3Vi^HF0?ooo`<0i^KVn@3oool100000040oooo00000`00
0000oooo0?ooo`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`40
00000@3oool000030000003oool0oooo0?l0oooo703oool100000040oooo00000`000000oooo0?oo
o`3o0?oooa`0oooo0@0000010?ooo`0000<000000?ooo`3oool0o`3ooolL0?ooo`4000000@3oool0
00030000003oool0oooo0?l0oooo703oool100000040oooo003o0000020000000@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.54629, -2.54629, 0.366176, \
0.366176}}],

Cell[BoxData[
    \({0.017997000000000696`\ Second, {\(-0.41028550006137643`\), \
\(-0.3125097520875344`\), \(-0.2542271364624169`\), \
\(-0.23879781115580043`\), \(-0.18685183515368337`\)}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{575, 600},
WindowMargins->{{Automatic, 174}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "matrixrepresentationvc"->{
    Cell[1823, 55, 2434, 74, 308, "Usage",
      CellTags->{
      "matrixrepresentationvc", "matrixrepresentationvcsparse", 
        "matrixrepresentationvcfast", "matrixrepresentationop", 
        "makematricesbzvc", "makematricesbzop"}]},
  "matrixrepresentationvcsparse"->{
    Cell[1823, 55, 2434, 74, 308, "Usage",
      CellTags->{
      "matrixrepresentationvc", "matrixrepresentationvcsparse", 
        "matrixrepresentationvcfast", "matrixrepresentationop", 
        "makematricesbzvc", "makematricesbzop"}]},
  "matrixrepresentationvcfast"->{
    Cell[1823, 55, 2434, 74, 308, "Usage",
      CellTags->{
      "matrixrepresentationvc", "matrixrepresentationvcsparse", 
        "matrixrepresentationvcfast", "matrixrepresentationop", 
        "makematricesbzvc", "makematricesbzop"}]},
  "matrixrepresentationop"->{
    Cell[1823, 55, 2434, 74, 308, "Usage",
      CellTags->{
      "matrixrepresentationvc", "matrixrepresentationvcsparse", 
        "matrixrepresentationvcfast", "matrixrepresentationop", 
        "makematricesbzvc", "makematricesbzop"}]},
  "makematricesbzvc"->{
    Cell[1823, 55, 2434, 74, 308, "Usage",
      CellTags->{
      "matrixrepresentationvc", "matrixrepresentationvcsparse", 
        "matrixrepresentationvcfast", "matrixrepresentationop", 
        "makematricesbzvc", "makematricesbzop"}]},
  "makematricesbzop"->{
    Cell[1823, 55, 2434, 74, 308, "Usage",
      CellTags->{
      "matrixrepresentationvc", "matrixrepresentationvcsparse", 
        "matrixrepresentationvcfast", "matrixrepresentationop", 
        "makematricesbzvc", "makematricesbzop"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"matrixrepresentationvc", 154106, 3097},
  {"matrixrepresentationvcsparse", 154384, 3103},
  {"matrixrepresentationvcfast", 154660, 3109},
  {"matrixrepresentationop", 154932, 3115},
  {"makematricesbzvc", 155198, 3121},
  {"makematricesbzop", 155464, 3127}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 44, 0, 38, "ObjectName"],
Cell[1823, 55, 2434, 74, 308, "Usage",
  CellTags->{
  "matrixrepresentationvc", "matrixrepresentationvcsparse", 
    "matrixrepresentationvcfast", "matrixrepresentationop", 
    "makematricesbzvc", "makematricesbzop"}],
Cell[4260, 131, 368, 17, 24, "Notes"],

Cell[CellGroupData[{
Cell[4653, 152, 42, 0, 38, "ExampleSection"],
Cell[4698, 154, 117, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[4840, 162, 213, 4, 58, "Input"],
Cell[5056, 168, 103, 2, 21, "Print"]
}, Open  ]],
Cell[5174, 173, 51, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[5250, 177, 153, 3, 42, "Input"],
Cell[5406, 182, 21441, 524, 108, "Output"]
}, Open  ]],
Cell[26862, 709, 157, 5, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[27044, 718, 249, 5, 74, "Input"],
Cell[27296, 725, 26745, 526, 210, "Output"]
}, Open  ]],
Cell[54056, 1254, 75, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[54156, 1258, 375, 10, 42, "Input"],
Cell[54534, 1270, 4343, 106, 312, "Output"]
}, Open  ]],
Cell[58892, 1379, 85, 1, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[59002, 1384, 135, 3, 42, "Input"],
Cell[59140, 1389, 34911, 720, 250, "Output"]
}, Open  ]],
Cell[94066, 2112, 132, 3, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[94223, 2119, 431, 11, 58, "Input"],
Cell[94657, 2132, 4343, 106, 312, "Output"],
Cell[99003, 2240, 63, 2, 25, "Output"]
}, Open  ]],
Cell[99081, 2245, 68, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[99174, 2249, 1060, 23, 218, "Input"],
Cell[100237, 2274, 193, 4, 21, "Print"],
Cell[100433, 2280, 84, 2, 25, "Output"],
Cell[100520, 2284, 94, 2, 25, "Output"],
Cell[100617, 2288, 94, 2, 25, "Output"],
Cell[100714, 2292, 63, 2, 25, "Output"],
Cell[100780, 2296, 63, 2, 25, "Output"]
}, Open  ]],
Cell[100858, 2301, 152, 3, 50, "ExampleText"],

Cell[CellGroupData[{
Cell[101035, 2308, 214, 6, 42, "Input"],
Cell[101252, 2316, 51930, 753, 294, 21218, 369, "GraphicsData", "PostScript", \
"Graphics"],
Cell[153185, 3071, 229, 4, 41, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

