(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31515,        818]*)
(*NotebookOutlinePosition[     32467,        852]*)
(*  CellTagsIndexPosition[     32365,        845]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["orthogvc", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["orthogvc[", "MR"],
  StyleBox["vecs", "IT"],
  StyleBox[", ", "MR"],
  StyleBox["basis", "IT"],
  "] orthogonalizes a list of vectors ",
  StyleBox["vecs", "IT"],
  " in the occupation number representation basis ",
  StyleBox["basis", "IT"],
  ".\n\[FilledSmallSquare] ",
  StyleBox["orthogop[", "MR"],
  StyleBox["vecs", "IT"],
  StyleBox[", ", "MR"],
  StyleBox["basis", "IT"],
  "] orthogonalizes a list of vectors ",
  StyleBox["vecs", "IT"],
  " in the creation operator representation basis ",
  StyleBox["basis", "IT"],
  "."
}], "Usage",
  CellTags->{"orthogvc", "orthogop"}],

Cell[TextData[{
  "\[FilledSmallSquare] Vectors are first decomposed in the given basis using \
",
  ButtonBox["decomposevc",
    ButtonStyle->"AddOnsLink"],
  " or ",
  ButtonBox["decomposeop",
    ButtonStyle->"AddOnsLink"],
  ", then ",
  ButtonBox["Householder",
    ButtonStyle->"RefGuideLink"],
  " is called to perform the orthogonalization.\n\[FilledSmallSquare] ",
  ButtonBox["Householder",
    ButtonStyle->"AddOnsLink"],
  " is restricted to numeric matrices, therefore only vectors with numeric \
coefficients are allowed."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["scalarproductop",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["scalarproductvc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["decomposevc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["decomposeop",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " to be a fermionic operator"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Creation operator representation", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bz = makebasis[{c[1], c[2]}]\), "\[IndentingNewLine]", 
    \(vecs = {c[CR, 1, UP] + c[CR, 2, UP], 
        c[CR, 1, UP] + 2  c[CR, 2, UP]}\), "\[IndentingNewLine]", 
    \(orthogop[vecs, bz]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {1, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"1", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {1, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {2, 
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], ",", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                RowBox[{"2", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {2, 
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "+", 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], ",", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], "+", 
          RowBox[{"2", " ", 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}]}], "}"}]], "Output",
  CellLabel->"Out[4]="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          FractionBox[
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"1", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {1, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], \(\@2\)], "+", 
          FractionBox[
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], \(\@2\)]}], ",", 
        RowBox[{
          RowBox[{"-", 
            FractionBox[
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], \(\@2\)]}], "+", 
          FractionBox[
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    RowBox[{"2", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {2, 
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], \(\@2\)]}]}], "}"}]], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["Occupation number representation", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bvc = ap[bz, VACUUM]\), "\[IndentingNewLine]", 
    \(vecsvc = ap[vecs, VACUUM]\), "\[IndentingNewLine]", 
    \(orthogvc[vecsvc, bvc]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            TagBox[
              StyleBox["\<\"\[FilledRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[FilledRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[FilledRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm], ",", 
        TagBox[
          RowBox[{
            TagBox[
              StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[EmptyRectangle]\"\>",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
            TagBox[
              StyleBox["\<\"\[FilledRectangle]\"\>",
                FontColor->RGBColor[0, 0, 1]],
              (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
            TagBox[
              StyleBox["\<\"\[RightAngleBracket]\"\>",
                FontColor->RGBColor[0, 0.392187, 0]],
              (
              StyleForm[ #, FontColor -> RGBColor[ 
                0.0, 0.39219300000000001, 0.0]]&)]}],
          DisplayForm]}], "}"}]], "Output",
  CellLabel->"Out[6]="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
              TagBox[
                StyleBox["\<\"\[FilledRectangle]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
              TagBox[
                StyleBox["\<\"\[RightAngleBracket]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm], "+", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              TagBox[
                StyleBox["\<\"\[FilledRectangle]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
              TagBox[
                StyleBox["\<\"\[RightAngleBracket]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm]}], ",", 
        RowBox[{
          RowBox[{"2", 
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[FilledRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[RightAngleBracket]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm]}], "+", 
          TagBox[
            RowBox[{
              TagBox[
                StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)], 
              TagBox[
                StyleBox["\<\"\[FilledRectangle]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
              TagBox[
                StyleBox["\<\"\[EmptyRectangle]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
              TagBox[
                StyleBox["\<\"\[RightAngleBracket]\"\>",
                  FontColor->RGBColor[0, 0.392187, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  0.0, 0.39219300000000001, 0.0]]&)]}],
            DisplayForm]}]}], "}"}]], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          FractionBox[
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[FilledRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[RightAngleBracket]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], \(\@2\)], "+", 
          FractionBox[
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                TagBox[
                  StyleBox["\<\"\[FilledRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[RightAngleBracket]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], \(\@2\)]}], ",", 
        RowBox[{
          FractionBox[
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[FilledRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[RightAngleBracket]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], \(\@2\)], "-", 
          FractionBox[
            TagBox[
              RowBox[{
                TagBox[
                  StyleBox["\<\"\[LeftDoubleBracketingBar]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)], 
                TagBox[
                  StyleBox["\<\"\[FilledRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
                TagBox[
                  StyleBox["\<\"\[EmptyRectangle]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
                TagBox[
                  StyleBox["\<\"\[RightAngleBracket]\"\>",
                    FontColor->RGBColor[0, 0.392187, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0.0, 0.39219300000000001, 0.0]]&)]}],
              DisplayForm], \(\@2\)]}]}], "}"}]], "Output",
  CellLabel->"Out[8]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{673, 771},
WindowMargins->{{Automatic, 92}, {Automatic, 133}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "orthogvc"->{
    Cell[1809, 55, 639, 21, 54, "Usage",
      CellTags->{"orthogvc", "orthogop"}]},
  "orthogop"->{
    Cell[1809, 55, 639, 21, 54, "Usage",
      CellTags->{"orthogvc", "orthogop"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"orthogvc", 32154, 835},
  {"orthogop", 32255, 838}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 30, 0, 38, "ObjectName"],
Cell[1809, 55, 639, 21, 54, "Usage",
  CellTags->{"orthogvc", "orthogop"}],
Cell[2451, 78, 549, 16, 62, "Notes"],
Cell[3003, 96, 339, 14, 24, "Notes"],

Cell[CellGroupData[{
Cell[3367, 114, 42, 0, 38, "ExampleSection"],
Cell[3412, 116, 117, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3554, 124, 139, 3, 42, "Input"],
Cell[3696, 129, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3814, 134, 55, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3894, 138, 250, 5, 58, "Input"],
Cell[4147, 145, 3014, 81, 33, "Output"],
Cell[7164, 228, 3313, 86, 33, "Output"],
Cell[10480, 316, 3602, 90, 53, "Output"]
}, Open  ]],
Cell[14097, 409, 55, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[14177, 413, 193, 4, 58, "Input"],
Cell[14373, 419, 5352, 127, 25, "Output"],
Cell[19728, 548, 5726, 130, 25, "Output"],
Cell[25457, 680, 6018, 133, 45, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

